/*
 * Copyright (c) 2018, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: MIT
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/MIT
 */
import { LogLevel } from '../../types/index.js';
import { UNRECOGNIZED_MESSAGE_TYPE } from '../../labels.js';
/**
 * This class represents a WebSocket connection.
 * It provides methods to marshal and unmarshal data between hmr-client and dev server.
 */
export class Connection {
    constructor(socket, logger) {
        this.socket = socket;
        this.logger = logger;
    }
    close() {
        this.socket.close();
    }
    isReady() {
        return this.socket.readyState === this.socket.OPEN;
    }
    send(data) {
        if (this.isReady()) {
            this.socket.send(JSON.stringify(data));
        }
    }
    receive(callback) {
        if (!this.isReady()) {
            this.logger.log(LogLevel.debug, 'Connection not ready to receive data from server.');
            return;
        }
        this.socket.addEventListener('message', ({ data }) => {
            if (typeof data === 'string') {
                const payload = JSON.parse(data);
                callback(payload);
            }
            else {
                this.logger.log(LogLevel.error, UNRECOGNIZED_MESSAGE_TYPE);
                this.socket.close();
            }
        });
    }
}
//# sourceMappingURL=connection.js.map