import { FSWatcher } from 'chokidar';
import * as Websocket from 'ws';
import { DevServerContext, type Logger, type ServerConfig } from '../types/index.js';
import { ClientPool } from './connection/client.js';
import type { WebSocketServer } from 'ws';
/**
 * This class represents the central place where the LWC dev server coordination occurs.
 *
 * ModuleGraph -> Is responsible for discovering modules and tracking changes to them
 * Connection -> An authenticated connection between hmr-client and dev server
 * Client -> A stateful object that tracks a hmr-client connected to the dev server
 *
 * This class also manages resources that will need clean up, like the file watcher, WebSockets.
 */
export declare class LWCServer {
    watcher: FSWatcher;
    clientPool: ClientPool;
    wss: WebSocketServer;
    context: DevServerContext;
    constructor(config: ServerConfig, wss: WebSocketServer, logger: Logger);
    /**
     * Initialize the WebSocketServer by adding message handlers for connections lifecycle events.
     */
    init(): void;
    stopServer(): void;
    moduleUpdateHandler(modulePath: string): void;
    /**
     * A one time message handler for new clients.
     * This method is responsible for authenticating the client connection and once authenticated,
     * the communication is handed over to the Client object.
     */
    newClientMessageCallback({ data: rawData, target: socket }: Websocket.MessageEvent): void;
    clientCloseHandler({ target: socket }: Websocket.ErrorEvent | Websocket.CloseEvent): void;
}
/**
 * Initialize an LWC Dev Server with the specified server configuration.
 * @returns Returns an initialized LWC dev server.
 */
export declare function startLwcDevServer(config: ServerConfig): Promise<LWCServer>;
